#!/usr/bin/ksh

# Install script for FireScope Agent for AIX

####################################################################################################
# Variables
####################################################################################################
INSTALLERLOG="/var/tmp/firescope_agent_install.log"
VERSION=4.0.22
FSMUSER="root"
FSMGROUP="system"
FSUSER="firescop"
FSGROUP="firescop"
CURDIR=`pwd`
CINAME=`uname -n`
BASEDIR="/opt/firescope"
AGENTDIR="$BASEDIR/agent"
MANAGERDIR="$BASEDIR/agent_manager"
AIX_5_BINS="$CURDIR/agent/AIX_5"
AIX_6_BINS="$CURDIR/agent/AIX_6"
AIX_7_BINS="$CURDIR/agent/AIX_7"
AGENT_PID_DEST_FILES="$AGENTDIR/logs"
JMX_INSTALL_FILES_DIR="$CURDIR/jmxdelegate"
JAVAMIN="2"
JAVAMAX="5"
JMXDIR="$AGENTDIR/modules/jmxdelegate"
JAVAPATH=`which java`
APORT="8042"
SPORT="8043"
MPORT="8044"
JPORT="8046"
DACTIVE="0"
UPGRADE="0"
JMX="false"
RMTCMD="1"
REALTIME="1"
STORETIME="300"
STORECOUNT="100"
CONFIGFILE="${AGENTDIR}/conf/firescope_agentd_posix.xml"
CONFIGFILEBASE="${AGENTDIR}/conf"
RELEASENOTESSOURCE="${CURDIR}/ReleaseNotes.txt"
RELEASENOTESDEST="$BASEDIR/agent/docs/ReleaseNotes.txt"
INIT="/etc/rc.d/init.d"
INIT2="/etc/rc.d/rc2.d"
INIT5="/etc/rc.d/rc5.d"
INSTALLER="FireScope_Agent_Installer.sh"
CPUCHK=`oslevel -r`
DATE=`date`
WHOAMI=`id | cut -d "(" -f2 | cut -d ")" -f1`
####################################################################################################
# End - Variables
####################################################################################################
####################################################################################################
# functions
####################################################################################################

    #################################################################################
    # FireScope Agent Help Function
    #################################################################################
    show_help () {
        HELPUSAGE="$INSTALLER -A XXX.XXX.XXX.XXX [ options ]"
        HELPAPPLIANCE="-A : Appliance IP or DNS name. Usage FireScope_Agent_Installer.sh -a XXX.XXX.XXX.XXX(Required - IP or DNS Name to FireScope Appliance.)"
        HELPBASEINTALLPATH="-b : InstallPath - Path to install the FireScope Agent. default - /opt/firescope"
        HELPREMOTECOMMAND="-c : RemoteCommand - Allows the FireScope Appliance to send commands to the agent to execute. default 0 (Valid 1 on - 0 off)"
        HELPDISABLEACTIVE="-d : DisableActive - Disables Active checks. default 0 (Valid 1 on - 0 off)"
        HELPHELP="-h : Help - Displays this help file"
        HELPHOSTNAME="-H : CINAME - Hostname or name used to ID the system in the FireScope Appliance. Must match for AgentRemote to work properly."
        HELPENABLEJMX="-J : JMXDelegate - Enables the JMX Delegate feature for this agent. default - false (valid true or false)"
        HELPJMXPORT="-j : JMXDelegate Port - Port used by the JMX Delegate. default - 8046 (Valid 1-65535)"
        HELPJAVAMEMMIN="-k : Java Heap Minimum size - the Minimum heap size in MB used by Java. default - 2"
        HELPJAVAMEMMAX="-K : Java Heap Maximum size - the Maximum heap size in MB used by Java. default - 5"
        HELPMANAGERPORT="-m : ManagerPort - Port used by the agent manager to receive data from the FireScope Appliance. default - 8044 (Valid 1-65535)"
        HELPSTORECOUNT="-n : Storecount - Used in Store&Foward mode. The number of metrics stored before sending. default - 100 (valid 10-200)"
        HELPAGENTPORT="-p : AgentPort - Port used by the agent to receive data from the FireScope Appliance. default - 8042 (Valid 1-65535)"
        HELPREALTIME="-s : Realtime - Sets the FireScope Agent to realtime mode. default - 1 (Valid 1-Realtime 0-Store&Forward)"
        HELPSTORETIME="-t : Storetime - Used in Store&Foward mode. The amount of time in seconds that the agent will cache metrics before sending. default - 300 (Valid 30 - 600)"
        HELPUPGRADE="-u : Upgrade - Used to upgrade a legacy firescope_agentd.conf to a firescope_agentd_posix.xml"
        HELPJVM="-V : JVM location - path to the Java Virtual Machine to be used by the JMXDelegate"
        HELPEXAMPLE="e.g. $INSTALLER -A 10.0.2.40 -b /opt/firescope -p 8042 -c 1 -H myserver -s 1 -t 200 -n 400"
        SHOW_HELP="$HELPUSAGE\n\t$HELPAPPLIANCE\n\t$HELPBASEINTALLPATH\n\t$HELPREMOTECOMMAND\n\t$HELPDISABLEACTIVE\n\t$HELPHELP\n\t$HELPHOSTNAME\n\t$HELPENABLEJMX\n\t$HELPJMXPORT\n\t$HELPJAVAMEMMIN\n\t$HELPJAVAMEMMAX\n\t$HELPMANAGERPORT\n\t$HELPSTORECOUNT\n\t$HELPAGENTPORT\n\t$HELPREALTIME\n\t$HELPSTORETIME\n\t$HELPUPGRADE\n\t$HELPJVM\n\t$HELPEXAMPLE"
        echo "$SHOW_HELP"
        exit 1
    }
    ####################################################################################################
    # Start - sedreplace function
    ####################################################################################################
    # Usage
    # sedreplace $1 $2 $3
    # $1 what to search for
    # $2 file to search in
    # $3 line offset in numbers
    # $4 what to replace with
    # e.g. sedreplace "AGENTDIR=AGENTDIR" "$INIT"/firescope_agentd 0 "AGENTDIR=$AGENTDIR"
    ####################################################################################################
    sedreplace () {
        AIModeKey=`grep -n "$1" "$2" | cut -d ":" -f1`
        echo "AIModeKey=$AIModeKey"  >>$INSTALLERLOG
        AIModeValue=`expr $AIModeKey + $3` >>$INSTALLERLOG
        echo "AIModeValue=$AIModeValue"  >>$INSTALLERLOG
        sedLine=`sed $AIModeValue'q;d' $2` >>$INSTALLERLOG
        echo "sedLine=$sedLine"  >>$INSTALLERLOG
        sedLine1=`echo $sedLine | cut -d '>' -f2 | cut -d '<' -f1`
        echo "sedLine1=$sedLine1"  >>$INSTALLERLOG
        sedLine2="$4" >>$INSTALLERLOG
        echo "sedLine2=$sedLine2"  >>$INSTALLERLOG
        cp -f "$2" "$2-old"
        sed -e "$AIModeValue"'s;'"$sedLine1"';'"$sedLine2"';g' $2 >> "$2-new"
        mv -f "$2-new" "$2"
        rm -f "$2-new"
    }
    ####################################################################################################
    # End - sedreplace function
    ####################################################################################################

    ####################################################################################################
    # Agent init sed replace function
    ####################################################################################################
    agent_init_sed () {
        echo "****************************Agent init set agent path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "AGENTDIR=AGENTDIR" "$INIT"/firescope_agentd 0 "AGENTDIR=$AGENTDIR"
        echo "****************************Agent init set config path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT"/firescope_agentd 0 "agentd_cfgfile=$CONFIGFILE"
        echo "****************************Agent init set pid path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "pidfile=pidfile" "$INIT"/firescope_agentd 0 "pidfile=$AGENTDIR/logs/"
        echo "****************************Agent init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "FSUSER=FSUSER" "$INIT"/firescope_agentd 0 "FSUSER=$FSUSER"
    }
    ####################################################################################################
    # End - Agent init sed replace function
    ####################################################################################################

    ####################################################################################################
    # Agent Manager init sed replace function
    ####################################################################################################
    agent_manager_init_sed () {
        echo "****************************Agent manager init set agent path 'Agent Manager init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "MANAGERDIR=MANAGERDIR" "$INIT"/firescope_agent_managerd 0 "MANAGERDIR=$MANAGERDIR"
        echo "****************************Agent manager init set config path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT"/firescope_agent_managerd 0 "agentd_cfgfile=$CONFIGFILE"
        echo "****************************Agent manager init set pid path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "pidfile=pidfile" "$INIT"/firescope_agent_managerd 0 "pidfile=$AGENTDIR/logs/"
        echo "****************************Agent manager init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
            sedreplace "FSMUSER=FSMUSER" "$INIT"/firescope_agent_managerd 0 "FSMUSER=$FSMUSER"
    }
    ####################################################################################################
    # End - Agent Manager init sed replace function
    ####################################################################################################

    ####################################################################################################
    # Uninstaller sed replace function
    ####################################################################################################
    uninstaller_sed () {
    echo "****************************Agent uninstall dir. 'Uninstaller sed replace function '***************************" >>$INSTALLERLOG
        sedreplace "INIT=INIT" "$AGENTDIR"/FireScope_Agent_Uninstall.sh 0 "INIT=$INIT"
        sedreplace "INSTALLDIR=INSTALLDIR" "$AGENTDIR"/FireScope_Agent_Uninstall.sh 0 "INSTALLDIR=$BASEDIR"
            rm "$AGENTDIR"/FireScope_Agent_Uninstall.sh-old
    }
    ####################################################################################################
    # End - Uninstaller sed replace function
    ####################################################################################################

    ####################################################################################################
    # Setup init function
    ####################################################################################################
    setup_init () {
          if [ $JavaMinOptCalled -eq "0" ]; then
                if [ -f "$CONFIGFILE" ]; then
                    JAVAMIN=`cat $CONFIGFILE | grep -m 1 -o -e "Xms[^a-zA-Z]\{1,\}m" | grep -o -e "[^a-zA-Z]\{1,\}"
                else
                    JAVAMIN=2
                fi
          else
                if [ $JAVAMIN > $JAVAMAX ]; then
                    JAVAMIN = $JAVAMAX - 1
                fi
          fi

          if [ $JavaMaxOptCalled -eq "0" ]; then
                if [ -f "$CONFIGFILE" ]; then
                    JAVAMAX=`cat $CONFIGFILE | grep -m 1 -o -e "Xmx[^a-zA-Z]\{1,\}m" | grep -o -e "[^a-zA-Z]\{1,\}"
                else
                    JAVAMAX=5
                fi
          else
                if [ $JAVAMIN > $JAVAMAX ]; then
                    JAVAMAX = $JAVAMIN + 1
                fi
          fi

                SERVICE_START="$INIT/firescope_agentd start"
                SERVICE_STOP="$INIT/firescope_agentd stop"
            ####################################################################################################
            # Agent init sed replace
            ####################################################################################################
                agent_init_sed
                chmod +x "$INIT"/firescope_agentd
            if [ "$SKIPAGENTMANAGER" != "1" ]; then
            ####################################################################################################
            # Agent Manger init sed replace
            ####################################################################################################
                agent_manager_init_sed
                chmod +x "$INIT"/firescope_agent_managerd
            else
                echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped init of manager" >>$INSTALLERLOG
            fi
    }
####################################################################################################
# End - functions
####################################################################################################

if [ -f "$INSTALLERLOG" ]; then
    rm -f $INSTALLERLOG
fi
###########################
# FireScope Agent Getopts settings
###########################
f="0"
JavaMinOptCalled="0"
JavaMaxOptCalled="0"
while getopts ":A:a:b:c:d:H:J:j:K:k:m:n:p:s:t:V:huZ" o
do case $o in
    ###########################
    # FireScope Server Set Info
    ###########################
    A)
        f="1"
        echo "Checking for connectivity to the FireScope Appliance."
        echo "$DATE == $WHOAMI Passed1FireScopeServerIP=$OPTARG"  >>$INSTALLERLOG

#        if [[ "$OPTARG" =~ "^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])(\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])){3}$" ]]; then
        if [ "$OPTARG" != "" ]; then
            SERVERCHECK=`ping -c 3 $OPTARG | grep -c "3 received"`
            echo "$DATE == $WHOAMI Server Ping Check = ${SERVERCHECK}"  >>$INSTALLERLOG
            echo "Checking for route to Appliance. Please standby."
            if [ ${SERVERCHECK} != "1" ]; then
                echo "Could not ping the FireScope Server!!! Please check IP or DNS and try again."  >>$INSTALLERLOG
            fi
        else
            echo "Invalid IP address, please provide the FireScope appliance IP address."
            echo "$Installer -h more help."
            exit 1
        fi
        SERVER="$OPTARG"
        echo "$DATE == $WHOAMI Set1FireScopeServerIP=${SERVER}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Server Port
    ###########################
    a)
        echo "$DATE == $WHOAMI PassedServerPort=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
            SPORT="$OPTARG"
        else
            echo "Server Port (-a) must be between 1 and 65535!!!"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetServerPort=${SPORT}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Path
    ###########################
    b)
        echo "$DATE == $WHOAMI Passed2InstallPath=$OPTARG"  >>$INSTALLERLOG
        if [ "$OPTARG" = "" ]; then
            BASEDIR="/opt/firescope"
        elif [ "$OPTARG" != "" ]; then
            BASEDIR="$OPTARG"
            AGENTDIR="$BASEDIR/agent"
            MANAGERDIR="$BASEDIR/agent_manager"
            JMXDIR="$AGENTDIR/modules/jmxdelegate"
            CONFIGFILE="${BASEDIR}/agent/conf/firescope_agentd_posix.xml"
            CONFIGFILEBASE="${BASEDIR}/agent/conf"
            RELEASENOTESDEST="${BASEDIR}/agent/docs/ReleaseNotes.txt"
            AGENT_PID_DEST_FILES="$AGENTDIR/logs"
        fi
        echo "$DATE == $WHOAMI Set2InstallPath=${BASEDIR}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Port
    ###########################
    p)
        echo "$DATE == $WHOAMI Passed3Port=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
            APORT="$OPTARG"
        else
            echo "Agent Port (-p) must be between 1 and 65535!!!"
            exit 1
        fi
        echo "$DATE == $WHOAMI Set3Port=${APORT}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Manager Port
    ###########################
    m)
        echo "$DATE == $WHOAMI PassedManPort=$OPTARG"  >>$INSTALLERLOG
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
            MPORT="$OPTARG"
        else
            echo "Agent Manager Port (-m) must be between 1 and 65535!!!"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetManPort=${MPORT}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Remote Commands
    ###########################
    c)
        echo "$DATE == $WHOAMI PassedRMTCMD=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
        if [[ "$OPTARG" = "1" ]] || [[ "$OPTARG" = "0" ]]; then
            RMTCMD="$OPTARG"
        else
            RMTCMD="0"
            echo "Invalid Argument for Remote commands (-c)"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetRMTCMD=${RMTCMD}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Disable Active checks
    ###########################
    d)
        echo "$DATE == $WHOAMI PassedDActive=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
        if [[ "$OPTARG" = "1" ]] || [[ "$OPTARG" = "0" ]]; then
            DACTIVE="$OPTARG"
        else
            RMTCMD="0"
            echo "Invalid argument for Disable Active Checks (-d)"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetDActive=${DACTIVE}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent JMX Enable check
    ###########################
    J)
        echo "$DATE == $WHOAMI PassedJMX=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
        if [[ "$OPTARG" = "1" ]] || [[ "$OPTARG" = "0" ]]; then
            JMX="$OPTARG"
        else
            echo "Invalid argument for JMX Enable (-J)"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetJMX=$JMX"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent JMX PORT
    ###########################
    j)
        echo "$DATE == $WHOAMI PassedJMXPort=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
            JPORT="$OPTARG"
        else
            echo "JMX Port (-j) must be between 1 and 65535!!!"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetJMXPort=${JPORT}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Java Heap Memory MAX
    ###########################
    K)
         JavaMaxOptCalled="1"
        echo "$DATE == $WHOAMI PassedJavaMemMax=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "[^a-zA-Z]\{1,\}" ]] && [ "$OPTARG" -gt "0" ]; then
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "0" ]; then
            JAVAMAX="$OPTARG"
        else
            JAVAMAX="2"
        fi
        echo "$DATE == $WHOAMI SetJavaMemMax=${JAVAMAX}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Java Heap Memory MIN
    ###########################
    k)
        JavaMinOptCalled="1"
        echo "$DATE == $WHOAMI PassedJavaMemMin=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "[^a-zA-Z]\{1,\}" ]] && [ "$OPTARG" -gt "0" ]; then
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "1" ]; then
            JAVAMIN="$OPTARG"
        else
            JAVAMIN="5"
        fi
        echo "$DATE == $WHOAMI SetJavaMemMin=${JAVAMIN}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Hostname
    ###########################
    H)
        echo "$DATE == $WHOAMI PassedCINAME=$OPTARG"  >>$INSTALLERLOG
        if [ "$OPTARG" = "" ]; then
            CINAME=`hostname -s`
        fi
        if [ "$OPTARG" != "" ]; then
            CINAME="$OPTARG"
        fi
        echo "$DATE == $WHOAMI SetCINAME=${CINAME}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Realtime
    ###########################
    s)
        echo "$DATE == $WHOAMI PassedREALTIME=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
        if [[ "$OPTARG" = "1" ]] || [[ "$OPTARG" = "0" ]]; then
            REALTIME="$OPTARG"
        else
            echo "Invaild argument for Agent Realtime mode (-s)"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetREALTIME=${REALTIME}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Storetime
    ###########################
    t)
        echo "$DATE == $WHOAMI PassedSTORETIME=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "29" ] && [ "$OPTARG" -lt "601" ]; then
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "29" ] && [ "$OPTARG" -lt "601" ]; then
            STORETIME="$OPTARG"
        else
            echo "Invaild value for Store and Forward time (-t)"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetSTORETIME=${STORETIME}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent upgrade
    ###########################
    u)
        UPGRADE="1"
    ;;
    ###########################
    # Java Path check
    ###########################
    V)
        echo "$DATE == $WHOAMI PassedJVM=$OPTARG"  >>$INSTALLERLOG
        if [ "$OPTARG" = "" ]; then
            JVM=$JAVAPATH
        fi
        if [ "$OPTARG" != "" ]; then
            JVM="$OPTARG"
        fi
        echo "$DATE == $WHOAMI SetJVM=${STORETIME}"  >>$INSTALLERLOG
    ;;
    ###########################
    # FireScope Agent Storecount
    ###########################
    n)
        echo "$DATE == $WHOAMI PassedSTORECOUNT=$OPTARG"  >>$INSTALLERLOG
#        if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "9" ] && [ "$OPTARG" -lt "201" ]; then
        if [[ "$OPTARG" != "" ]] && [ "$OPTARG" -gt "9" ] && [ "$OPTARG" -lt "201" ]; then
            STORECOUNT="$OPTARG"
        else
            echo "Invalid value for Store and Forward Count (-n)"
            exit 1
        fi
        echo "$DATE == $WHOAMI SetSTORECOUNT=${STORECOUNT}"  >>$INSTALLERLOG
    ;;
    h)
        show_help; exit 0
    ;;
    Z)
        SKIPAGENTMANAGER="1"
    ;;
    \?)
        echo "Invalid option: -$OPTARG"
        echo "$Installer -h for more help."
        exit 1
    ;;
    :)
        echo "Option -$OPTARG requires an argument."
        echo "$Installer -h for more help."
        exit 1
    ;;
    esac
done

###########################
# FireScope Check for required flags
###########################
    if [ $UPGRADE -ne "1" ]; then
        if [ "$f" = "0" ]; then
            echo "The flag -A is required
            $INSTALLER -h for more help"
            exit 1
        elif [ "$1" = "-h" ]; then
            show_help
        elif [ "$1" = "--help" ]; then
            show_help
            exit 0
        fi
    fi
####################################################################################################
#Check if user is root
####################################################################################################
    if [ "${WHOAMI}" != "root" ]; then
        echo "Sorry, root required to install agent."
        exit 1
    fi
####################################################################################################
#End Check if user is root
####################################################################################################
echo "\033[40m\033[40;33m" #sets back gound to black
####################################################################################################
#checks if there is a service account on system
####################################################################################################
    #Begin Check
    #################################
    #Required Variables
    #################################
    # FSUSER
    # FSGROUP
    #################################
    echo "Service account check for Agent" >>$INSTALLERLOG
    IDTEST=`dispuid | grep $FSUSER`
    echo "IDTEST=$IDTEST" >>$INSTALLERLOG
    GRPTEST=`dispgid | grep $FSGROUP`
    echo "GRPTEST=$GRPTEST"  >>$INSTALLERLOG
    #IDUSERTEST=`id $FSUSER | awk '($1 ~ /\('$FSGROUP'\)/) && ($1 ~ /uid=/)' 2>/dev/null`
    COUNTER=0
    if [ -z "$GRPTEST" ]
        then
        echo "Creating Group: $FSGROUP"
            mkgroup $FSGROUP
    fi
    if [ -z "$IDTEST" ]
    then
        echo "Creating Service Account: $FSUSER"
        `useradd -g $FSUSER $FSGROUP 2>/dev/null`
    else
        echo "User and Groups exist, Upgrading Agent Installation...."
    fi
####################################################################################################
# Future error check code
####################################################################################################
#                    echo "Verifing Service Account"
#                        if [ -z "$IDUSERTEST" ]
#                            then
#                                while [  $COUNTER -lt 3 ]; do
#                                        echo "Cannot Create Service Account: firescop"
#                                let COUNTER=COUNTER+1
#                                done
####################################################################################################
################################
#End Check
################################
    echo "creating dir structure" >>$INSTALLERLOG
    mkdir -p $BASEDIR >>$INSTALLERLOG
    mkdir -p $AGENTDIR >>$INSTALLERLOG
    mkdir -p $AGENTDIR/bin >>$INSTALLERLOG
    mkdir -p $AGENTDIR/.agent >>$INSTALLERLOG
    mkdir -p $AGENTDIR/cache >>$INSTALLERLOG
    mkdir -p $AGENTDIR/conf >>$INSTALLERLOG
    mkdir -p $AGENTDIR/docs >>$INSTALLERLOG
    mkdir -p $AGENTDIR/logs >>$INSTALLERLOG
    mkdir -p $AGENTDIR/modules >>$INSTALLERLOG
    mkdir -p $AGENTDIR/modules/jmxdelegate >>$INSTALLERLOG
    mkdir -p $AGENTDIR/modules/jmxdelegate/jar >>$INSTALLERLOG
    mkdir -p $AGENTDIR/scripts >>$INSTALLERLOG
    mkdir -p $AGENTDIR/backup >>$INSTALLERLOG
    if [ "$SKIPAGENTMANAGER" != "1" ]; then    
        mkdir -p $MANAGERDIR >>$INSTALLERLOG
        mkdir -p $MANAGERDIR/.agent_manager >>$INSTALLERLOG
        mkdir -p $MANAGERDIR/temp >>$INSTALLERLOG
   else
        echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped mkdir of manager" >>$INSTALLERLOG
   fi

################################
# Echo to $INSTALLERLOG
################################

    echo "$DATE == $WHOAMI mkdir Variables" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/modules=$AGENTDIR/modules" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate=$AGENTDIR/modules/jmxdelegate" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate/jar=$AGENTDIR/modules/jmxdelegate/jar" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$INSTALLERLOG
    echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$INSTALLERLOG
    if [ "$SKIPAGENTMANAGER" != "1" ]; then    
        echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$INSTALLERLOG
        echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$INSTALLERLOG
        echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$INSTALLERLOG
    else
        echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped echo of manager" >>$INSTALLERLOG
    fi

################################
# Echo to $MANAGERDIR/.agent_manager/agent_paths
################################

    echo "$DATE == $WHOAMI mkdir Variables" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/modules=$AGENTDIR/modules" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate=$AGENTDIR/modules/jmxdelegate" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate/jar=$AGENTDIR/modules/jmxdelegate/jar" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$MANAGERDIR/.agent_manager/agent_paths
    echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$MANAGERDIR/.agent_manager/agent_paths
    if [ "$SKIPAGENTMANAGER" != "1" ]; then    
        echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$MANAGERDIR/.agent_manager/agent_paths
        echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$MANAGERDIR/.agent_manager/agent_paths
        echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$MANAGERDIR/.agent_manager/agent_paths
    else
        echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped agent paths of manager" >>$INSTALLERLOG
    fi
############################
# Presentation
############################
    echo "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent $VERSION Installer for AIX\n===============================================\n"
####################################################################################################
# Copy core files
####################################################################################################
    echo "$CPUCHK" >>$INSTALLERLOG
    # Check here for currently supported 5.x OSs https://www-304.ibm.com/support/docview.wss?uid=isg1SSRVAIX53TL10081505_508
    if [ $CPUCHK = "5300-10" ] || [ $CPUCHK = "5300-11" ]; then 
        ####################################################################################################
        # Copy agent files AIX 5
        ####################################################################################################
        echo "Copying AIX 5 Agent bin" >>$INSTALLERLOG
        cp $AIX_5_BINS/firescope_agentd $AGENTDIR/bin/firescope_agentd >>$INSTALLERLOG
        cp $RELEASENOTESSOURCE RELEASENOTESDEST >>$INSTALLERLOG
        ####################################################################################################
        # Copy agent manager files AIX 5
        ####################################################################################################
        if [ "$SKIPAGENTMANAGER" != "1" ]; then
            echo "Copying AIX 5 Agent Manager bins" >>$INSTALLERLOG
            cp $AIX_5_BINS/firescope_agent_managerd $MANAGERDIR
            cp $AIX_5_BINS/minizip $MANAGERDIR
            cp $AIX_5_BINS/miniunzip $MANAGERDIR
        else
            echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped upgrading manager" >>$INSTALLERLOG
        fi
    # Check here for currently supported 5.x OSs https://www-304.ibm.com/support/docview.wss?uid=isg1SSRVAIX61TL01081504_906
    elif [ $CPUCHK = "6100-01" ] || [ $CPUCHK = "6100-02" ] || [ $CPUCHK = "6100-03" ] || [ $CPUCHK = "6100-04" ] || [ $CPUCHK = "6100-05" ] || [ $CPUCHK = "6100-06" ] || [ $CPUCHK = "6100-07" ]; then 
        ####################################################################################################
        # Copy agent files AIX 6
        ####################################################################################################
        echo "Copying AIX 6 Agent bin" >>$INSTALLERLOG
        cp $AIX_6_BINS/firescope_agentd $AGENTDIR/bin/firescope_agentd >>$INSTALLERLOG
        cp $RELEASENOTESSOURCE RELEASENOTESDEST >>$INSTALLERLOG
        ####################################################################################################
        # Copy agent manager files AIX 6
        ####################################################################################################
        if [ "$SKIPAGENTMANAGER" != "1" ]; then
            echo "Copying AIX 6 Agent Manager bins" >>$INSTALLERLOG
            cp $AIX_6_BINS/firescope_agent_managerd $MANAGERDIR
            cp $AIX_6_BINS/minizip $MANAGERDIR
            cp $AIX_6_BINS/miniunzip $MANAGERDIR
        else
            echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped upgrading manager" >>$INSTALLERLOG
        fi
    elif [ $CPUCHK = "7100-00" ] || [ $CPUCHK = "7100-01" ]; then 
        ####################################################################################################
        # Copy agent files AIX 7
        ####################################################################################################
        echo "Copying AIX 7 Agent bin" >>$INSTALLERLOG
        cp $AIX_7_BINS/firescope_agentd $AGENTDIR/bin/firescope_agentd >>$INSTALLERLOG
        cp $RELEASENOTESSOURCE RELEASENOTESDEST >>$INSTALLERLOG
        ####################################################################################################
        # Copy agent manager files AIX 7
        ####################################################################################################
        if [ "$SKIPAGENTMANAGER" != "1" ]; then
            echo "Copying AIX 7 Agent Manager bins" >>$INSTALLERLOG
            cp $AIX_7_BINS/firescope_agent_managerd $MANAGERDIR
            cp $AIX_7_BINS/minizip $MANAGERDIR
            cp $AIX_7_BINS/miniunzip $MANAGERDIR
        else
            echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped upgrading manager" >>$INSTALLERLOG
        fi
    else
        echo "Unsupported Operating System $CPUCHK"
    fi
    echo "Copying AIX Agent Uninstaller script" >>$INSTALLERLOG
    cp $CURDIR/agent/FireScope_Agent_Uninstall.sh $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG
####################################################################################################
# End - Copy core files
####################################################################################################

####################################################################################################
# Copy delegate files
####################################################################################################
    ####################################################################################################
    # Copy JMXDelegate
    ####################################################################################################
    cp $JMX_INSTALL_FILES_DIR/jar/jmxdelegate.jar $AGENTDIR/modules/jmxdelegate/jar >>$INSTALLERLOG
    ####################################################################################################
    # End - Copy JMXDelegate
    ####################################################################################################
####################################################################################################
# End - Copy delegate files
####################################################################################################

####################################################################################################
# chmod agent and agent manager bins
####################################################################################################
        chmod +x $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG
        chmod +x $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar >>$INSTALLERLOG
        chmod +x $AGENTDIR/bin/firescope_agentd >>$INSTALLERLOG
        if [ "$SKIPAGENTMANAGER" != "1" ]; then
            chmod +x $MANAGERDIR/firescope_agent_managerd >>$INSTALLERLOG
            chmod +x $MANAGERDIR/miniunzip >>$INSTALLERLOG
            chmod +x $MANAGERDIR/minizip >>$INSTALLERLOG
        else
            echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chmod manager" >>$INSTALLERLOG
        fi
####################################################################################################
# End - chmod agent and agent manager bins
####################################################################################################

########################################################################################################
# Setup INIT with OS check
########################################################################################################
####################################################################################################
# Available Runlevels (AIX)
####################################################################################################
# ID            Name              Description
####################################################################################################
# 0                                 reserved
# 1                                 reserved
#*2     Normal Multi-User mode      default mode
# 3                                 defined by the admin
# 4                                 defined by the admin
# 5                                 defined by the admin
# 6                                 defined by the admin
# 6                                 defined by the admin
# 7                                 defined by the admin
# 8                                 defined by the admin
# 9                                 defined by the admin
####################################################################################################
    echo "cpuchk" >>$INSTALLERLOG
    echo "$CPUCHK" >>$INSTALLERLOG
#    if [ $CPUCHK = "powerpc" ]; then
        ####################################################################################################
        # Copy agent init files AIX with manager upgrade check
        ####################################################################################################
        cp $CURDIR/init/firescope_agentd $INIT/firescope_agentd >>$INSTALLERLOG
            if [ "$SKIPAGENTMANAGER" != "1" ]; then
                cp $CURDIR/init/firescope_agent_managerd $INIT/firescope_agent_managerd >>$INSTALLERLOG
            else
                echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped copy init manager" >>$INSTALLERLOG
            fi
        ####################################################################################################
        # End -  Copy agent init files AIX with manager upgrade check
        ####################################################################################################

        ####################################################################################################
        # Link agent init files with runlevels AIX with manager upgrade check
        ####################################################################################################
        if [ `lsitab -a | grep -c fsagentd` -eq "0" ]; then
            mkitab "fsagentd:2:boot:$INIT/firescope_agentd start > /dev/console 2>&1" >>$INSTALLERLOG
        fi
        ####################################################################################################
        # End - Link agent init files with runlevels AIX with manager upgrade check
        ####################################################################################################

        ####################################################################################################
        # Link agent manager init files with runlevels AIX with manager upgrade check
        ####################################################################################################
        if [ "$SKIPAGENTMANAGER" != "1" ]; then
             if [ `lsitab -a | grep -c fsmanagerd` -eq "0" ]; then
                  mkitab "fsmanagerd:2:boot:$INIT/firescope_agent_managerd start > /dev/console 2>&1" >>$INSTALLERLOG
             fi
        else
            echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped link init manager" >>$INSTALLERLOG
        fi
        ####################################################################################################
        # End - Link agent manager init files with runlevels AIX with manager upgrade check
        ####################################################################################################

        ####################################################################################################
        # Chmod agent init files AIX with manager upgrade check
        ####################################################################################################
        chmod +x $INIT/firescope_agentd >>$INSTALLERLOG
        if [ "$SKIPAGENTMANAGER" != "1" ]; then
            chmod +x $INIT/firescope_agent_managerd >>$INSTALLERLOG
        else
            echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chmod manager" >>$INSTALLERLOG
        fi
        ####################################################################################################
        # End - Chmod agent init files AIX with manager upgrade check
        ####################################################################################################

#    fi
########################################################################################################
# End - Setup INIT with OS check
#######################################################################################################

####################################################################################################
# Set some user input and collected values in config file
####################################################################################################
    setup_init

    ###############################################
    # check for .conf and convert
    ###############################################
        if [ -f $CONFIGFILEBASE/firescope_agentd.conf ]; then
            echo "### Conf upgrade conf --> xml ###" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd.conf -u "" >>$INSTALLERLOG
                    echo 'Upgrading conf--->xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd.conf -u ""' >>$INSTALLERLOG
                    echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
    ###############################################
    # check for .xml and convert
    ###############################################
    elif [ -f $CONFIGFILEBASE/firescope_agentd_posix.xml ]; then >>$INSTALLERLOG
        echo "### Conf upgrade xml --> xml ###"  >>$INSTALLERLOG
            $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "" >>$INSTALLERLOG
                 echo 'Upgrading xml--->xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u ""' >>$INSTALLERLOG
                 echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
            echo "Upgrading old xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u JmxDelegateEnable=$JMX|JmxDelegatePort=$JPORT|JmxDelegateCommand=$JAVAPATH -Xms${JAVAMIN}m -Xmx${JAVAMAX}m|JmxDelegateParameters=-jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt; /dev/null|SocketTimeoutMillisec=1000|LocalSocketTimeoutMillisec=1000" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "JmxDelegateParameters=-Xms${JAVAMIN}m -Xmx${JAVAMAX}m -jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt; /dev/null" >>$INSTALLERLOG
    ###############################################
    # create new config xml file
    ###############################################
    else
        echo "### New Config XML Created ###" >>$INSTALLERLOG
        ####################################################################################################
        # New Config xml created
        ####################################################################################################
            echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
            echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd.conf -u AgentServiceName=firescope_agentd|AgentServiceStart=$SERVICE_START|AgentServiceStop=$SERVICE_STOP" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "AgentServiceName=firescope_agentd|AgentServiceStart=$SERVICE_START|AgentServiceStop=$SERVICE_STOP" >>$INSTALLERLOG
            echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE" >>$INSTALLERLOG
            echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/firescope_agentd.log|PidFile=$AGENTDIR/logs/firescope_agentd.pid" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/firescope_agentd.log|PidFile=$AGENTDIR/logs/firescope_agentd.pid" >>$INSTALLERLOG
            echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
            echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/firescope_agent_managerd.log|ManagerPidFile=$AGENTDIR/logs/firescope_agent_managerd.pid" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/firescope_agent_managerd.log|ManagerPidFile=$AGENTDIR/logs/firescope_agent_managerd.pid" >>$INSTALLERLOG
            echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u JmxDelegateEnable=$JMX|JmxDelegatePort=$JPORT|JmxDelegateCommand=$JAVAPATH|JmxDelegateParameters=-Xms${JAVAMIN}m -Xmx${JAVAMAX}m -jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt; /dev/null|SocketTimeoutMillisec=1000|LocalSocketTimeoutMillisec=1000" >>$INSTALLERLOG
                $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "JmxDelegateEnable=$JMX|JmxDelegatePort=$JPORT|JmxDelegateCommand=$JAVAPATH|JmxDelegateParameters=-Xms${JAVAMIN}m -Xmx${JAVAMAX}m -jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt; /dev/null|SocketTimeoutMillisec=1000|LocalSocketTimeoutMillisec=1000" >>$INSTALLERLOG
    fi

    uninstaller_sed
####################################################################################################
# End - Set some user input and collected values in config file
####################################################################################################
####################################################################################################
# Chmod uninstall.sh script
####################################################################################################
    chmod +x $AGENTDIR/FireScope_Agent_Uninstall.sh
####################################################################################################
# Chown the firescope directory and all child directory to be owned by firescop
####################################################################################################
    chown -R $FSUSER:$FSGROUP $BASEDIR >>$INSTALLERLOG
    if [ "$SKIPAGENTMANAGER" != "1" ]; then
        chown -R $FSMUSER:$FSMGROUP $MANAGERDIR >>$INSTALLERLOG
    else
        echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chown of manager dir" >>$INSTALLERLOG
    fi
####################################################################################################
# Install Completed
####################################################################################################
echo "FireScope Agent v$VERSION for AIX has been installed."
#
echo "\
\n\
Starting FireScope Agent $VERSION for AIX\n\
===============================================\n\
\n\
"
#
    $INIT/firescope_agentd start >>$INSTALLERLOG
        if [ "$SKIPAGENTMANAGER" != "1" ]; then
            $INIT/firescope_agent_managerd start >>$INSTALLERLOG
        else
            echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped start init manager old style" >>$INSTALLERLOG
        fi
#
echo "\
\n\
FireScope Agent $VERSION for AIX is now running.\n\
===============================================\n\
\n\
"
        echo "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent v$VERSION for AIX installation and startup complete!!!.\n=================================================================\n\n"
        echo "\033[0m" # sets background back to default
exit 0
